@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: persistent
 version: 2.2.4.1
-id: persistent-2.2.4.1-d8d907c8c62628a6667ab3fa39fc892f
-key: persi_FsSRrdTzyvp1qGLhPcIYzr
+id: persistent-2.2.4.1-53b32e0b8931dd68fbb356ac374c65f3
+key: persi_J2ytUYAzvbAKKp3CvCQURI
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -35,7 +35,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-2.2.4.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-2.2.4.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-2.2.4.1
-hs-libraries: HSpersistent-2.2.4.1-FsSRrdTzyvp1qGLhPcIYzr
+hs-libraries: HSpersistent-2.2.4.1-J2ytUYAzvbAKKp3CvCQURI
 depends:
     aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
     attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
@@ -51,7 +51,7 @@ depends:
     http-api-data-0.2.2-d85b0db99d6d5995d772ab01cd2ae49e
     lifted-base-0.2.3.6-9c13caa8bbd360a88b87891885feeeff
     monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
-    monad-logger-0.3.18-f3d00babf6bfa7ff698db362dc267041
+    monad-logger-0.3.18-1374b457a8b7165408364c0bd477c532
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
     path-pieces-0.2.1-f62a4ee86afe2692f9fb79d2dd895499
